network_monitoring library
Classes
- DevModeOptionsView
- Dev mode settings: HTTP monitoring toggle, overlay, remote monitor, and breakpoints.
- NetworkMonitorChanges
- Common subscription groups used by package widgets and host apps.
- NetworkMonitoring
- Singleton entry point for the package.
- NetworkMonitoringBuilder
-
Rebuilds when selected
NetworkMonitorControllerstate changes. - NetworkMonitoringConfig
- Configuration for the NetworkMonitoring package.
- NetworkMonitoringLocalizations
-
Callers can lookup localized strings with an instance of NetworkMonitoringLocalizations
returned by
NetworkMonitoringLocalizations.of(context). - NetworkMonitorOverlayWrapper
-
Wraps the app content and syncs the floating network monitor overlay
visibility with
NetworkMonitorController.isOverlayVisible. - VersionTapDetector
- Wraps child and counts taps to unlock dev mode via NetworkMonitoringConfig.
Enums
- NetworkMonitorChange
- Specific controller state domains that UI can subscribe to independently.
Mixins
-
NetworkMonitorControllerListener<
T extends StatefulWidget> - Mixin for State widgets that need to rebuild on controller changes.
Functions
Typedefs
-
DevModePasswordValidator
= FutureOr<
bool> Function(String password) - Validates user input from the dev mode password dialog.
-
OpenUrl
= FutureOr<
void> Function(String url) - Host-provided handler for opening a URL (e.g. the remote monitor page).
- Host-provided handler for sharing text from the monitoring UI.